=======
Credits
=======

Maintainers
-----------

* Hugo Perrier <hugo.perrier@maif.fr>

Contributors
------------

* Florian Arthur
* Guillaume Bernard
* Victor Bigand
* Tiphaine Fabre
* Marouane Il Idrissi
* Benoit Lebreton
* Hugo Perrier
* Sacha Samama
* Antoine Simoulin
* Tom Stringer

To be continued ...
